@@ -10,10 +10,10 @@ DESCRIPTION
     Parallel parallelizes otherwise non-parallel command-line tasks. When
     there are a number of commands that need to be executed, which may be
     executed in parallel, the Parallel application will evenly distribute
-    tasks to all available CPU cores. There are three basic methods for how
+    tasks to all available CPU cores. There are three bascuic methods for how
     commands are supplied:
 
-    1. A COMMAND may be defined, followed by an  which denotes
+    1. A COMMAND may be defined, followed by a MODE which denotes
        that all following arguments will be usde as INPUTS for the command.
 
     2. If no COMMAND is provided, then the INPUTS will be interpreted as
@@ -56,6 +56,11 @@ INPUT TOKENS
     -  {#}: Displays the current job ID as a number counting from 1.
     - {#^}: Displays the total number of jobs to be processed.
     -  {%}: Displays the thread's ID number.
+    -  {N}: Where N is a number, display the associated job number.
+    - {N.}: will remove the extension from the Nth job.
+    -  {/}: Displays the base name (file name) of the input.
+    - {//}: Displays the directory name of the input.
+    - {/.}: Displays the base name with the extension removed.
 
 OPTIONS
     Options may also be supplied to the program to change how the program
