@@ -21,6 +21,8 @@ pub struct Args {
     ///
     /// **NOTE:** This has a large performance cost.
     pub uses_shell: bool,
+    /// Evaluates to true if the first argument is either `:::` or `::::`.
+    pub inputs_are_commands: bool,
     /// If set to true, the application will print information about running tasks.
     pub verbose:    bool,
     /// The command arguments collected as a list of `Token`s
@@ -41,6 +43,7 @@ pub enum ParseErr {
     InvalidArgument(String),
 }
 
+#[derive(PartialEq)]
 enum Mode {
     Arguments,
     Command,
@@ -51,9 +54,20 @@ enum Mode {
 
 impl Args {
     pub fn parse(&mut self) -> Result<(), ParseErr> {
-        let mut mode = Mode::Arguments;
         let mut raw_args = env::args().skip(1).peekable();
         let mut comm = String::with_capacity(2048);
+
+        // The purpose of this is to set the initial parsing mode.
+        let mut mode = match raw_args.peek().unwrap().as_ref() {
+            ":::"  => Mode::Inputs,
+            "::::" => Mode::Files,
+            _      => Mode::Arguments
+        };
+
+        // If there are no arguments to be parsed, then the inputs are commands.
+        self.inputs_are_commands = mode == Mode::Inputs || mode == Mode::Files  ;
+
+        // Parse each and every input argument supplied to the program.
         while let Some(argument) = raw_args.next() {
             let argument = argument.as_str();
             match mode {
@@ -69,28 +83,22 @@ impl Args {
                             // command line arguments, to allow for laziness.
                             if character == 'j' {
                                 // The short-hand job argument needs to be handled specially.
-                                if char_iter.peek().is_some() {
+                                self.ncores = if char_iter.peek().is_some() {
                                     // Each character that follows after `j` will be considered an
                                     // input value.
-                                    match jobs::parse(&argument[2..]) {
-                                        Ok(ncores) => self.ncores = ncores,
-                                        Err(err)   => return Err(err)
-                                    }
+                                    try!(jobs::parse(&argument[2..]))
                                 } else {
                                     // If there wasn't a character after `j`, the argument must
                                     // be supplied as the following argument.
-                                    match raw_args.peek() {
-                                        Some(val) => match jobs::parse(val) {
-                                            Ok(ncores) => self.ncores = ncores,
-                                            Err(err)   => return Err(err)
-                                        },
+                                    match raw_args.next() {
+                                        Some(ref val) => try!(jobs::parse(val)),
                                         None => return Err(ParseErr::JobsNoValue)
                                     }
-                                    let _ = raw_args.next();
                                 }
                             } else if character != '-' {
                                 // All following characters will be considered their own argument.
-                                for character in argument[1..].chars() {
+                                let mut char_iter = argument[1..].chars();
+                                while let Some(character) = char_iter.next() {
                                     match character {
                                         'h' => {
                                             println!("{}", man::MAN_PAGE);
@@ -112,14 +120,10 @@ impl Args {
                                         exit(0);
                                     },
                                     "jobs" => {
-                                        match raw_args.peek() {
-                                            Some(val) => match jobs::parse(val) {
-                                                Ok(ncores) => self.ncores = ncores,
-                                                Err(err)   => return Err(err)
-                                            },
+                                        self.ncores = match raw_args.next() {
+                                            Some(ref val) => try!(jobs::parse(val)),
                                             None => return Err(ParseErr::JobsNoValue)
-                                        }
-                                        let _ = raw_args.next();
+                                        };
                                     },
                                     "ungroup" => self.grouped = false,
                                     "no-shell" => self.uses_shell = false,
@@ -138,9 +142,21 @@ impl Args {
                             return Err(ParseErr::InvalidArgument("-".to_owned()));
                         }
                     } else {
-                        // The command has been supplied, and argument parsing is over.
-                        comm.push_str(argument);
-                        mode = Mode::Command;
+                        match argument {
+                            ":::" => {
+                                mode = Mode::Inputs;
+                                self.inputs_are_commands = true;
+                            },
+                            "::::" => {
+                                mode = Mode::Files;
+                                self.inputs_are_commands = true;
+                            }
+                            _ => {
+                                // The command has been supplied, and argument parsing is over.
+                                comm.push_str(argument);
+                                mode = Mode::Command;
+                            }
+                        }
                     }
                 },
                 Mode::Command => match argument {
@@ -159,9 +175,7 @@ impl Args {
                     "::::" => mode = Mode::Files,
                     _ => match mode {
                         Mode::Inputs => self.inputs.push(argument.to_owned()),
-                        Mode::Files => if let Err(why) = file_parse(&mut self.inputs, argument) {
-                            return Err(why)
-                        },
+                        Mode::Files => try!(file_parse(&mut self.inputs, argument)),
                         _ => unreachable!()
                     }
                 }
@@ -174,9 +188,7 @@ impl Args {
         if self.inputs.is_empty() {
             let stdin = io::stdin();
             for line in stdin.lock().lines() {
-                if let Ok(line) = line {
-                    self.inputs.push(line)
-                }
+                if let Ok(line) = line { self.inputs.push(line) }
             }
         }
 
@@ -186,14 +198,10 @@ impl Args {
 
 /// Attempts to open an input argument and adds each line to the `inputs` list.
 fn file_parse(inputs: &mut Vec<String>, path: &str) -> Result<(), ParseErr> {
-    fs::File::open(path)
-        .map_err(|err| ParseErr::InputFileError(path.to_owned(), err.to_string()))
-        .map(|file| {
-            for line in BufReader::new(file).lines() {
-                if let Ok(line) = line {
-                    inputs.push(line);
-                }
-            }
-            ()
-        })
+    let file = try!(fs::File::open(path)
+        .map_err(|err| ParseErr::InputFileError(path.to_owned(), err.to_string())));
+    for line in BufReader::new(file).lines() {
+        if let Ok(line) = line { inputs.push(line); }
+    }
+    Ok(())
 }
