@@ -16,12 +16,8 @@ use std::sync::mpsc::channel;
 use arguments::{Args, ParseErr};
 use pipe::State;
 
-/* TODO: Functionality can be increased to accept the following syntaxes from GNU Parallel:
- - {N}, {N.}, etc.
- - parallel command {1} {2} {3} ::: 1 2 3 ::: 4 5 6 ::: 7 8 9
- - paralllel command ::: a b c :::+ 1 2 3 ::: d e f :::+ 4 5 6
- - Grouping currently only prints stdout/stderr of processes that are finished, instead
-   of printing while they are running.
+/* TODO: Possible features that could be integrated:
+ - Benchmarking
  - SSH support
 */
 
@@ -36,6 +32,7 @@ fn main() {
         grouped: true,
         uses_shell: true,
         verbose: false,
+        inputs_are_commands: false,
         arguments: Vec::new(),
         inputs: Vec::new()
     };
@@ -48,7 +45,7 @@ fn main() {
         let _ = stderr.write(b"parallel: parsing error: ");
         match why {
             ParseErr::InputFileError(file, why) => {
-                let _ = write!(&mut stderr, "unable to open {}: {}", file, why);
+                let _ = write!(&mut stderr, "unable to open {}: {}\n", file, why);
             },
             ParseErr::JobsNaN(value) => {
                 let _ = write!(&mut stderr, "jobs parameter, '{}', is not a number.\n", value);
@@ -63,9 +60,6 @@ fn main() {
         exit(1);
     }
 
-    // If no command argument was given, then the inputs are actually commands themselves.
-    let inputs_are_commands = args.arguments.is_empty();
-
     // It will be useful to know the number of inputs, to know when to quit.
     let num_inputs = args.inputs.len();
 
@@ -93,7 +87,7 @@ fn main() {
         // The base command template that each thread will use.
         let arguments = args.arguments.clone();
         // Allow the thread to gain access to the list of inputs.
-        let input = shared_input.clone();
+        let inputs = shared_input.clone();
         // Allow the thread to access the input counter
         let counter = shared_counter.clone();
         // Allow the thread to know when it's time to stop.
@@ -104,6 +98,8 @@ fn main() {
         let uses_shell = args.uses_shell;
         // If set to true, this will print the current processing task.
         let verbose_enabled = args.verbose;
+        // If no command arguments were given, then the inputs will be read as commands.
+        let inputs_are_commands = args.inputs_are_commands;
         // Each thread will receive it's own sender for sending stderr/stdout buffers.
         let output_tx = output_tx.clone();
 
@@ -125,7 +121,7 @@ fn main() {
                     // Atomically increment the counter
                     let counter = counter.fetch_add(1, Ordering::SeqCst);
                     // Check to see if all inputs have already been processed
-                    if counter >= num_inputs { break } else { (&input[counter], (counter + 1)) }
+                    if counter >= num_inputs { break } else { (&inputs[counter], (counter + 1)) }
                 };
 
                 if verbose_enabled {
@@ -175,7 +171,7 @@ fn main() {
                     // used on the condition that this value is set.
                     let mut child = unsafe { mem::uninitialized::<Child>() };
 
-                    match command.exec(grouped, uses_shell, &mut child) {
+                    match command.exec(grouped, uses_shell, &mut child, &inputs ) {
                         // If grouping is enabled, then we have an output to process.
                         Ok(command::CommandResult::Grouped) => {
                             pipe::output(child, job_id, &output_tx)
